%define name    intel-media
%define version 25.3.0
%define rel     1

%define major     7
%define libname   %mklibname igfxcmrt %{major}
%define develname %mklibname igfxcmrt -d

Name:           %{name}
Version:        %{version}
Release:        %mkrel %{rel}
Summary:        Hardware-accelerated video processing on Intel integrated GPUs Library
Group:          System/Kernel and hardware
License:        MIT
URL:            https://github.com/intel/media-driver
Source0:        %{url}/archive/%{name}-%{version}.tar.gz
#
Patch0:         intel-media-fix-cmake40.patch

# patches from git upstream
#

BuildRequires:  cmake
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(igdgmm) >= 12.3.0
BuildRequires:  pkgconfig(libdrm_intel)
BuildRequires:  pkgconfig(pciaccess)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(ocl-icd)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(libva)
BuildRequires:  intel-gmmlib-devel >= 22.3.20

# This package relies on igdgmm which relies on intel asm
ExclusiveArch:  x86_64

%description
Intel Media SDK provides a plain C API to access hardware-accelerated video
decode, encode and filtering on Intel Gen graphics hardware platforms.
Implementation written in C++ 11 with parts in C-for-Media (CM).

Supported video encoders: HEVC, AVC, MPEG-2, JPEG, VP9 Supported video decoders:
HEVC, AVC, VP8, VP9, MPEG-2, VC1, JPEG Supported video pre-processing filters:
Color Conversion, Deinterlace, Denoise, Resize, Rotate, Composition

%package -n     vaapi-driver-%{name}
Summary:        Hardware-accelerated video processing driver for VAAPI Intel
Group:          System/Kernel and hardware
 
%description -n vaapi-driver-%{name}
This package contains the driver needed to access hardware 
 

%package -n     %{libname}
Summary:        Hardware-accelerated video processing on Intel integrated GPUs Library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}
 
%description -n %{libname}
This package contains the library needed to run programs dynamically
linked with igfxcmrt library.
 
%package -n     %{develname}
Summary:        SDK for hardware-accelerated video processing on Intel integrated GPUs
Group:          Development/C++
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}
 
%description -n %{develname}
This package contains the headers that programmers will need to develop
applications which will use igfxcmrt library.

%files -n vaapi-driver-%{name}
%{_libdir}/dri/*_drv_video.so
 
%files -n %{libname}
%{_libdir}/libigfxcmrt.so.%{major}{,.*}
 
%files -n %{develname}
%dir %{_includedir}/igfxcmrt
%{_includedir}/igfxcmrt/cm_*.h
%{_libdir}/libigfxcmrt.so
%{_libdir}/pkgconfig/igfxcmrt.pc


%prep
%autosetup -p1 -n media-driver-intel-media-%{version}

# Fixes for gcc15 (please follow https://github.com/intel/media-driver/issues/1922 for upstream fixes)
#
#  See: https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99578#c43
#  Set compiler option "--param=min-pagesize=0" for some files
%if %{mgaversion} > 9
sed -e "/set(TMP_1_SOURCES_/i set_source_files_properties(\\
    \${CMAKE_CURRENT_LIST_DIR}/media_ddi_encode_hevc.cpp\\
    \${CMAKE_CURRENT_LIST_DIR}/decode_sub_packet_manager.cpp\\
    PROPERTIES COMPILE_OPTIONS \"--param=min-pagesize=0\"\\
)\\
"   -i media_driver/linux/common/codec/ddi/media_srcs.cmake
%endif

%build
%cmake \
    -DBUILD_DISPATCHER=ON \
    -DBUILD_SAMPLES=OFF \
    -DBUILD_TESTS=ON \
    -DBUILD_TOOLS=OFF \
    -DENABLE_OPENCL=ON \
    -DENABLE_WAYLAND=ON \
    -DENABLE_X11=ON \
    -DENABLE_X11_DRI3=ON \
    -DUSE_SYSTEM_GTEST=ON
#    -DMEDIA_BUILD_FATAL_WARNINGS=OFF

%cmake_build

%install
%cmake_install


%changelog
* Thu Jul 17 2025 ghibo <ghibo> 25.3.0-1.mga10
+ Revision: 2256938
- Update to version 25.3.0

* Sun Jul 06 2025 ghibo <ghibo> 25.2.6-1.mga10
+ Revision: 2247261
- Add further fixes for cmake-4.0
- Re-add another patch for cmake-4.0
- Update to version 25.2.6.
- Drop CMake minimal requirement, no longer requires.
- Add reminder for gcc15 fixes.

* Wed Jun 11 2025 daviddavid <daviddavid> 25.2.4-1.mga10
+ Revision: 2190584
- Fix required minimum version for cmake-4.0
- Fix error: "array subscript 0 is outside array bounds of 'void [0]' [-Werror=array-bounds=]"
  1) use targeted compiler option "--param=min-pagesize=0"
     See thread at: https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99578#c43
  Or
  2) use global cmake option "-DMEDIA_BUILD_FATAL_WARNINGS=OFF"
  (thanks to Aurelian R)
+ ghibo <ghibo>
- Update to version 25.2.4
- Update to version 25.2.3
- Update to version 25.2.2
- Update to version 25.2.1

* Mon Jan 20 2025 ghibo <ghibo> 25.1.0-0.mga10
+ Revision: 2139981
- Update to version 25.1.0

* Sun Dec 01 2024 ghibo <ghibo> 24.4.3-1.mga10
+ Revision: 2120386
- Update to version 24.4.3

* Tue Nov 12 2024 ghibo <ghibo> 24.4.2-1.mga10
+ Revision: 2114664
- Update to version 24.4.2

* Sun Oct 20 2024 ghibo <ghibo> 24.4.0-1.mga10
+ Revision: 2108797
- Update to version 24.4.0

* Tue Jul 30 2024 ghibo <ghibo> 24.3.0-0.mga10
+ Revision: 2082937
- Update to version 24.3.0.
- Merge patches from git upstream.

* Mon Jul 01 2024 ghibo <ghibo> 24.2.5-1.mga10
+ Revision: 2078523
- Update to release 24.2.5.
- Merge patches from git upstream.
- Fix gmmlib BR.
- Update to version 24.1.5

* Thu Feb 22 2024 ghibo <ghibo> 24.1.3-1.mga10
+ Revision: 2043164
- Update to version 24.1.3.
- Merge patches from git upstream.

* Sat Dec 16 2023 ghibo <ghibo> 23.4.3-1.mga10
+ Revision: 2018325
- Update to version 23.4.3.
- Drop patches merged upstream.

* Tue Sep 19 2023 ghibo <ghibo> 23.3.3-1.mga10
+ Revision: 1988064
- Update to release 23.3.3.
- Merge patches from git upstream.

* Sat Mar 18 2023 ghibo <ghibo> 23.1.3-2.mga9
+ Revision: 1949666
- Merge patch from git upstream to fix a memleak

* Sat Mar 18 2023 ghibo <ghibo> 23.1.3-1.mga9
+ Revision: 1949643
- Update to release 23.1.3.
- Drop patches merged upstream.

* Sat Feb 25 2023 ghibo <ghibo> 23.1.2-1.mga9
+ Revision: 1945394
- Update to release 23.1.2.
- Merge patch from git upstream to fix jpeg decode MD5 mismatch.
- Merge patch from git upstream to fix NULL pointer issue.

* Thu Feb 09 2023 ghibo <ghibo> 23.1.1-1.mga9
+ Revision: 1939727
- Update to release 23.1.1.
- Drop Patch0, merged upstream.
- Versioning igdgmm in BuildRequires.

* Thu Mar 31 2022 kekepower <kekepower> 22.3.0-1.mga9
+ Revision: 1836901
- Add upstream patch to fix build with gcc 12.0.1
- Update to version 22.3.0
- Update to version 22.1.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Jul 10 2020 zezinho <zezinho> 20.2.0-1.mga8
+ Revision: 1604322
- new version 20.2.0

* Mon Apr 06 2020 zezinho <zezinho> 19.3.0-2.mga8
+ Revision: 1565321
- fix url

* Mon Apr 06 2020 zezinho <zezinho> 19.3.0-1.mga8
+ Revision: 1565275
- imported package intel-media

